DirectoryScaffolder class final

Scaffolds the DDD directory structure for a single feature.

Constructors

DirectoryScaffolder({required String featureName})

Properties

featureName String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getHostPackageName() String
Read the package name from pubspec.yaml in the current directory.
installMissingDependencies({required bool isFlutter, bool offline = false}) Future<void>
Reads the pubspec.yaml file, automatically adds missing dependencies, and runs pub get to resolve them.
isFlutterProject() bool
Returns true if the current project is a Flutter project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scaffold({bool withDebugView = false}) Map<String, Directory>
Create the DDD layer directories for this feature.
scaffoldExists() bool
Returns true if the feature directory already exists.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited