DirectoryScaffolder class final
Scaffolds the DDD directory structure for a single feature.
Constructors
- DirectoryScaffolder({required String featureName})
Properties
- featureName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getHostPackageName(
) → String -
Read the package name from
pubspec.yamlin the current directory. -
installMissingDependencies(
{required bool isFlutter, bool offline = false}) → Future< void> -
Reads the pubspec.yaml file, automatically adds missing dependencies,
and runs
pub getto resolve them. -
isFlutterProject(
) → bool -
Returns
trueif the current project is a Flutter project. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scaffold(
{bool withDebugView = false}) → Map< String, Directory> - Create the DDD layer directories for this feature.
-
scaffoldExists(
) → bool -
Returns
trueif the feature directory already exists. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited