DomainClass class final
Describes a generated Freezed domain model class.
Constructors
-
DomainClass({required String className, required List<
DomainField> fields, required String dtoClassName, bool isCore = false}) -
const
Properties
- className → String
-
The PascalCase class name (includes the
Modelsuffix, e.g.'UserModel').final - dtoClassName → String
-
The corresponding DTO class name used when generating
toDomain().final -
fields
→ List<
DomainField> -
Ordered list of fields in the generated model.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCore → bool
-
trueif this is the root response model for the feature.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited